==> 0.3.0%2B1.tar.gz: ios/Classes/Classes/SwiftSnowmScannerPlugin.swift <==
import Flutter
import UIKit

public class SwiftSnowmScannerPlugin: NSObject, FlutterPlugin {
    var beaconScanner = BeaconScanner()
    var permissionManager = PermissionManager()
    var mqttHelper = MqttHelper()
    var channel: FlutterMethodChannel?
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "snowm_scanner", binaryMessenger: registrar.messenger())
        let instance = SwiftSnowmScannerPlugin()
        instance.channel = channel
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        let method = call.method
        if method.contains("scanBeacons"){
            let arguments  = call.arguments as! NSDictionary
            let uuids:[String]  = arguments["uuids"] as! [String]
            //TODO: Trigger mqtt protocol on native side
            let enableMqtt:Bool  =  arguments["enableMqtt"] as! Bool
            beaconScanner.scanBeacons(method:method, uuids: uuids) { (beacons) -> () in
                if enableMqtt {
                    beacons.forEach { (beacon) in
                        self.mqttHelper.sendBeaconData(beacons:beacon)
                    }
                }
                self.sendBeaconResponse(method:method, beacons: beacons)
            }
            result(true)
        } else if method == "requestPermission"{
            result(permissionManager.requestPermission())
        } else if method == "permissionState"{
            result(permissionManager.permissionStatus)
        } else if method == "bluetoothState"{
            result(permissionManager.state)
        } else if method.contains( "bluetoothStateListener"){
            permissionManager.bluetoothState(method: method) { (state) in
                self.sendBluetoothStateResponse(method: method, state: state)
            }
            result(true)
        } else if method == "cancelBluetoothStateListener"{
            let arguments  = call.arguments as! NSDictionary
            let streamIdentifier = arguments["methodName"] as! String
            permissionManager.removeBluetoothState(identifier: streamIdentifier)
            result(true)
        } else if method == "cancelStream"{
            let arguments  = call.arguments as! NSDictionary
            let streamIdentifier = arguments["methodName"] as! String
            beaconScanner.removeScanner(identifier: streamIdentifier)
            result(true)
        } else if method == "scanBeaconBackground"{
            let arguments  = call.arguments as! NSDictionary
            let uuids:[String]  = arguments["uuids"] as! [String]
            let customData:Dictionary = arguments["customData"] as! Dictionary<String, Any>
            BackgroundBeaconScanner.shared.scanBeacons(uuids: uuids, customData: customData)
            result(true)
        } else if method == "stopBackgroundScan"{
            BackgroundBeaconScanner.shared.removeScanner()
            result(true)
        }
    }
    
    private func sendBluetoothStateResponse(method:String, state:String){
        channel?.invokeMethod(method, arguments: state)
    }
    
    private func sendBeaconResponse(method:String, beacons: [SnowMBeacon]){
        var response: [AnyHashable:Any] = [AnyHashable:Any]();
        response["beacons"] = beacons.map{ $0.toObject()};
        channel?.invokeMethod(method, arguments: response)
    }
}

==> 0.3.1%2B1.tar.gz: ios/Classes/Classes/SwiftSnowmScannerPlugin.swift <==
import Flutter
import UIKit
import CoreLocation

public class SwiftSnowmScannerPlugin: NSObject, FlutterPlugin {
    var beaconScanner = BeaconScanner()
    var permissionManager = PermissionManager()
    var mqttHelper = MqttHelper()
    var channel: FlutterMethodChannel?
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "snowm_scanner", binaryMessenger: registrar.messenger())
        let instance = SwiftSnowmScannerPlugin()
        instance.channel = channel
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        let method = call.method
        let arguments: Dictionary<String, Any>? = call.arguments as! Dictionary<String, Any>?
        if method.contains("scanBeacons"){
            let uuids:[String]  = arguments?["uuids"] as! [String]
            //TODO: Trigger mqtt protocol on native side
            let enableMqtt:Bool  =  arguments?["enableMqtt"] as! Bool
            beaconScanner.scanBeacons(method:method, uuids: uuids) { (beacons) -> () in
                if enableMqtt {
                    beacons.forEach { (beacon) in
                        self.mqttHelper.sendBeaconData(beacons:beacon)
                    }
                }
                self.sendBeaconResponse(method:method, beacons: beacons)
            }
            result(true)
        } else if method == "requestPermission"{
            result(permissionManager.requestPermission())
        } else if method == "permissionState"{
            result(permissionManager.permissionStatus)
        } else if method == "bluetoothState"{
            result(permissionManager.state)
        } else if method.contains( "bluetoothStateListener"){
            permissionManager.bluetoothState(method: method) { (state) in
                self.sendBluetoothStateResponse(method: method, state: state)
            }
            result(true)
        } else if method == "cancelBluetoothStateListener"{
            let streamIdentifier = arguments?["methodName"] as! String
            permissionManager.removeBluetoothState(identifier: streamIdentifier)
            result(true)
        } else if method == "cancelStream"{
            let streamIdentifier = arguments?["methodName"] as! String
            beaconScanner.removeScanner(identifier: streamIdentifier)
            result(true)
        } else if method == "scanBeaconBackground"{
            let uuids:[String]  = arguments?["uuids"] as! [String]
            let geofence:Dictionary? = (arguments?["geofence"] as! Dictionary<String, Any>)
            let customData:Dictionary = arguments?["customData"] as! Dictionary<String, Any>
            let backgroundScanner: BackgroundBeaconScanner = BackgroundBeaconScanner.shared
            backgroundScanner.scanBeacons(uuids: uuids, customData: customData)
            if(geofence != nil) {
                let radius: CLLocationDistance = geofence?["radius"] as! CLLocationDistance
                let point: CLLocationCoordinate2D = CLLocationCoordinate2D(latitude: geofence?["latitude"] as! CLLocationDegrees, longitude: geofence?["longitude"] as! CLLocationDegrees)
                backgroundScanner.addGeoFencing(location: point, radius: radius)
            }
            result(true)
        } else if method == "stopBackgroundScan"{
            let backgrounScanner: BackgroundBeaconScanner = BackgroundBeaconScanner.shared
            backgrounScanner.removeBeaconMonitoring()
            backgrounScanner.removeBeaconRanging()
            backgrounScanner.removeGeofencing()
            result(true)
        }
    }
    
    private func sendBluetoothStateResponse(method:String, state:String){
        channel?.invokeMethod(method, arguments: state)
    }
    
    private func sendBeaconResponse(method:String, beacons: [SnowMBeacon]){
        var response: [AnyHashable:Any] = [AnyHashable:Any]();
        response["beacons"] = beacons.map{ $0.toObject()};
        channel?.invokeMethod(method, arguments: response)
    }
}
